@@ -15,6 +15,7 @@ class Processor(object):
     def __init__(self, application, request):
         self.application = application
         self.request = request
+        self.status = 0
 
         try:
             self.event = request["headers"]["X-GitHub-Event"]
@@ -57,9 +58,11 @@ class Processor(object):
                     self.application.ioloop.add_timeout(self.application.interval, self.wait)
 
     def error(self, ex):
+        self.status = 2
         self.application.ioloop.add_timeout(self.application.interval, self.application.next)
 
     def success(self):
+        self.status = 1
         self.application.ioloop.add_timeout(self.application.interval, self.application.next)
 
     def wait(self):
@@ -92,7 +95,7 @@ class Application(tornado.web.Application):
     def __init__(self, config_filename="ci.yml", interval=1):
         super(Application, self).__init__([(".*", Handler)])
         self.queue = []
-        self.current = None
+        self.done = []
 
         self.ioloop = tornado.ioloop.IOLoop.instance()
 
@@ -105,17 +108,17 @@ class Application(tornado.web.Application):
         try:
             request = self.queue.pop(0)
         except IndexError:
-            self.current = None
             self.ioloop.add_timeout(self.interval, self.next)
         else:
-            self.current = Processor(self, request)
+            self.done.append(Processor(self, request))
 
 
 class Handler(tornado.web.RequestHandler):
     def get(self):
-        self.finish(json.dumps({
-            "queue": self.application.queue
-        }))
+        self.write("<pre>")
+        for job in self.application.done:
+            self.write("%50s %50s %50s\n" % (job.branch, job.event, job.status))
+        self.write("</pre>")
 
     def post(self):
         try:
